@@ -14,7 +14,7 @@ from i2llservice.utils import dyn16ToDec
 import time
 import random
 
-NOTE_COOLDOWN = 600
+NOTE_COOLDOWN = 3600 * 24
 CALLING_COOLDOWN = 20
 
 matcher = on_message()
